% Auto-generated chapter 20 for ibnmajah
% Hadiths in this chapter: 82

\hadithdefcmd{ibnmajah}{2533}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَشْرَفَ عَلَيْهِمْ فَسَمِعَهُمْ وَهُمْ، يَذْكُرُونَ الْقَتْلَ فَقَالَ إِنَّهُمْ لَيَتَوَاعَدُونِي بِالْقَتْلِ فَلِمَ يَقْتُلُونِي وَقَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لا يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ فِي إِحْدَى ثَلاَثٍ رَجُلٌ زَنَى وَهُوَ مُحْصَنٌ فَرُجِمَ أَوْ رَجُلٌ قَتَلَ نَفْسًا بِغَيْرِ نَفْسٍ أَوْ رَجُلٌ ارْتَدَّ بَعْدَ إِسْلاَمِهِ ‏"‏ ‏.‏ فَوَاللَّهِ مَا زَنَيْتُ فِي جَاهِلِيَّةٍ وَلاَ فِي إِسْلاَمٍ وَلاَ قَتَلْتُ نَفْسًا مُسْلِمَةً وَلاَ ارْتَدَدْتُ مُنْذُ أَسْلَمْتُ ‏.‏\hadithno{2533}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Umamah bin Sahl bin Hunaif that:`Uthman bin 'Affan looked at them when they spoke of killing. He said: “Are they kill threatening to kill me? Why would they kill me? I heard the Messenger of Allah (ﷺ) say: “It is not lawful to shed the blood of a Muslim except in one of three (cases): a man who commits adultery when he is a married person, then he should be stoned; a man who kills a soul not in retaliation for murder; and a man who apostatizes after becoming Muslim.' By Allah (SWT), I never committed adultery either during Ignorance days nor in Islam, and I have never killed a Muslim soul, and I have not apostatized since I became Muslim.”}}
\hadithdefcmd{ibnmajah}{2534}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ أَحَدُ ثَلاَثَةِ نَفَرٍ النَّفْسُ بِالنَّفْسِ وَالثَّيِّبُ الزَّانِي وَالتَّارِكُ لِدِينِهِ الْمُفَارِقُ لِلْجَمَاعَةِ ‏"‏ ‏.‏\hadithno{2534}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah, who is Ibn Mas`ud, that the Messenger of Allah (ﷺ) said:“It is not lawful to shed the blood of a Muslim who bears witness that none has the right to be worshiped but Allah (SWT), and that I am the Messenger of Allah (ﷺ), except in one of three cases: a soul for a soul; a married person who commits adultery, and one who leaves his religion and splits from the Jama`ah.”}}
\hadithdefcmd{ibnmajah}{2535}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏(‏مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏)‏‏.‏\hadithno{2535}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“Whoever changes his religion, execute him.”}}
\hadithdefcmd{ibnmajah}{2536}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقْبَلُ اللَّهُ مِنْ مُشْرِكٍ أَشْرَكَ بَعْدَ مَا أَسْلَمَ عَمَلاً حَتَّى يُفَارِقَ الْمُشْرِكِينَ إِلَى الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2536}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Bahz bin Hakim, from his father, from his grandfather that the Messenger of Allah (ﷺ) said:“Allah (SWT) will not accept any good deed from a polytheist who committed polytheism after having become Muslim, until he leaves the polytheists and joins the Muslims.”}}
\hadithdefcmd{ibnmajah}{2537}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا سَعِيدُ بْنُ سِنَانٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ أَبِي شَجَرَةَ، كَثِيرِ بْنِ مُرَّةَ عَنِ ابِنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِقَامَةُ حَدٍّ مِنْ حُدُودِ اللَّهِ خَيْرٌ مِنْ مَطَرِ أَرْبَعِينَ لَيْلَةً فِي بِلاَدِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2537}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn `Umar that the Messenger of Allah (ﷺ) said:“Carrying out one of the legal punishments prescribed by Allah (SWT) is better than if it were to rain for forty nights in the land of Allah (SWT), Glorified is He.”}}
\hadithdefcmd{ibnmajah}{2538}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَنْبَأَنَا عِيسَى بْنُ يَزِيدَ، أَظُنُّهُ عَنْ جَرِيرِ بْنِ يَزِيدَ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَدٌّ يُعْمَلُ بِهِ فِي الأَرْضِ خَيْرٌ لأَهْلِ الأَرْضِ مِنْ أَنْ يُمْطَرُوا أَرْبَعِينَ صَبَاحًا ‏"‏ ‏.‏\hadithno{2538}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A legal punishment that is carried out in the land is better for the people of that land than if it were to rain for forty days.”}}
\hadithdefcmd{ibnmajah}{2539}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَحَدَ آيَةً مِنَ الْقُرْآنِ فَقَدْ حَلَّ ضَرْبُ عُنُقِهِ وَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ فَلاَ سَبِيلَ لأَحَدٍ عَلَيْهِ إِلاَّ أَنْ يُصِيبَ حَدًّا فَيُقَامَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2539}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah said:“Whoever denies a Verse of the Qur'an, it is permissible to strike his neck (i.e., execute him) Whoever says, Lailaha illallahu wahduhu la sharika lahu, wa anna Muhammadan `abduhu wa rasuluhu (None has the right to be worshiped but Allah (SWT) alone, and Muhammad (ﷺ) is His slave and Messenger), no one has any was of harming him, unless he (does something which) deserves a legal punishment, and it is carried out on him.”}}
\hadithdefcmd{ibnmajah}{2540}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَالِمٍ الْمَفْلُوجُ، حَدَّثَنَا عُبَيْدَةُ بْنُ الأَسْوَدِ، عَنِ الْقَاسِمِ بْنِ الْوَلِيدِ، عَنْ أَبِي صَادِقٍ، عَنْ رَبِيعَةَ بْنِ نَاجِدٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَقِيمُوا حُدُودَ اللَّهِ فِي الْقَرِيبِ وَالْبَعِيدِ وَلاَ تَأْخُذْكُمْ فِي اللَّهِ لَوْمَةُ لاَئِمٍ ‏"‏ ‏.‏\hadithno{2540}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from `Ubadah bin Samit that the Messenger of Allah (ﷺ) said:“Carry out the legal punishments on relatives and strangers, and do not let the fear of blame stop you from carrying out the command of Allah (SWT).”}}
\hadithdefcmd{ibnmajah}{2541}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ عَطِيَّةَ الْقُرَظِيَّ، يَقُولُ عُرِضْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ قُرَيْظَةَ فَكَانَ مَنْ أَنْبَتَ قُتِلَ وَمَنْ لَمْ يُنْبِتْ خُلِّيَ سَبِيلُهُ فَكُنْتُ فِيمَنْ لَمْ يُنْبِتْ فَخُلِّيَ سَبِيلِي ‏.‏\hadithno{2541}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdul-Malik bin `Umair said:“I heard 'Atiyyah Al-Quradhi say: 'We were presented to the Messenger of Allah (ﷺ) on the Day of Quraidhah. Those whose pubic hair had grown were killed, and those whose pubic hair had not yet grown were let go. I was one of those whose pubic hair had not yet grown, so I was let go.”}}
\hadithdefcmd{ibnmajah}{2542}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ عَطِيَّةَ الْقُرَظِيَّ، يَقُولُ فَهَا أَنَا ذَا، بَيْنَ أَظْهُرِكُمْ ‏.‏\hadithno{2542}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdul-Malik bin 'Umair said:“I heard 'Atiyyah Al-Qurazi say: Here I am still among you,' ”}}
\hadithdefcmd{ibnmajah}{2543}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ وَأَبُو أُسَامَةَ قَالُوا حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ عُرِضْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ وَأَنَا ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً فَلَمْ يُجِزْنِي وَعُرِضْتُ عَلَيْهِ يَوْمَ الْخَنْدَقِ وَأَنَا ابْنُ خَمْسَ عَشْرَةَ سَنَةً فَأَجَازَنِي ‏.‏ قَالَ نَافِعٌ فَحَدَّثْتُ بِهِ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ فِي خِلاَفَتِهِ فَقَالَ هَذَا فَصْلُ مَا بَيْنَ الصَّغِيرِ وَالْكَبِيرِ ‏.‏\hadithno{2543}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn`Umar said:“I was presented to the Messenger of Allah (ﷺ) on the day of Uhud, when I was fourteen years old, but he did not permit me (to fight). I was presented to him on the Day of Khandaq when I was fifteen years old, and he permitted me (to fight).' ”}}
\hadithdefcmd{ibnmajah}{2544}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏\hadithno{2544}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever covers (the sin of) a Muslim, Allah will cover him (his sin) in this world and in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{2545}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا وَكِيعٌ، عَنْ إِبْرَاهِيمَ بْنِ الْفَضْلِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ادْفَعُوا الْحُدُودَ مَا وَجَدْتُمْ لَهُ مَدْفَعًا ‏"‏ ‏.‏\hadithno{2545}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Ward off the legal punishments as much as you can.”}}
\hadithdefcmd{ibnmajah}{2546}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، أَنْبَأَنَا مُحَمَّدُ بْنُ عُثْمَانَ الْجُمَحِيُّ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَتَرَ عَوْرَةَ أَخِيهِ الْمُسْلِمِ سَتَرَ اللَّهُ عَوْرَتَهُ يَوْمَ الْقِيَامَةِ وَمَنْ كَشَفَ عَوْرَةَ أَخِيهِ الْمُسْلِمِ كَشَفَ اللَّهُ عَوْرَتَهُ حَتَّى يَفْضَحَهُ بِهَا فِي بَيْتِهِ ‏"‏ ‏.‏\hadithno{2546}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn `Abbas that the Prophet (ﷺ) said:“Whoever conceals the (hidden) fault of his Muslim brother, Allah (SWT) will conceal his faults on the Day of Resurrection. Whoever exposes the fault of his Muslim brother, Allah will expose his faults, until (so that) He shames him, due to it, in his (own) house.”}}
\hadithdefcmd{ibnmajah}{2547}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالُوا وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَلَّمَهُ أُسَامَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاخْتَطَبَ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّمَا هَلَكَ الَّذِينَ مِنْ قَبْلِكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ رُمْحٍ سَمِعْتُ اللَّيْثَ بْنَ سَعْدٍ يَقُولُ قَدْ أَعَاذَهَا اللَّهُ عَزَّ وَجَلَّ أَنْ تَسْرِقَ قَدْ أَعَاذَهَا اللَّهُ عَزَّ وَجَلَّ أَنْ تَسْرِقَ وَكُلُّ مُسْلِمٍ يَنْبَغِي لَهُ أَنْ يَقُولَ هَذَا ‏.‏\hadithno{2547}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah :that Quraish became concerned about the case of the Makhzumi woman who had stolen, and they said: “Who will speak to the Messenger of Allah (ﷺ) concerning her?” They said: “Who would dare to do that other than Usamah bin Zaid, the beloved of the Messenger of Allah (ﷺ)?” So Usamah spoke to him, and the Messenger of Allah (ﷺ) said, “Are you interceding concerning one of the legal punishments of Allah (SWT)?“ Then he stood up and addressed (the people) and said: “O people! Those who came before you were only destroyed because when one of their nobles stole, they let him off, but when one of the weak people among them stole, they would carry out the punishment on him. By Allah, if Fatimah the daughter of Muhammad were to steal, I would cut off her hand.” (Sahih)(One of the narrators) Muhammad bin Rumh said: “I heard Laith bin Sa'd say: 'Allah(SWT) protected her (Fatimah) from stealing, and every Muslim should say this.'”}}
\hadithdefcmd{ibnmajah}{2548}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ طَلْحَةَ بْنِ رُكَانَةَ، عَنْ أُمِّهِ، عَائِشَةَ بِنْتِ مَسْعُودِ بْنِ الأَسْوَدِ عَنْ أَبِيهَا، قَالَ لَمَّا سَرَقَتِ الْمَرْأَةُ تِلْكَ الْقَطِيفَةَ مِنْ بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَعْظَمْنَا ذَلِكَ وَكَانَتِ امْرَأَةً مِنْ قُرَيْشٍ فَجِئْنَا إِلَى النَّبِيِّ صلى الله عليه وسلم نُكَلِّمُهُ وَقُلْنَا نَحْنُ نَفْدِيهَا بِأَرْبَعِينَ أُوقِيَّةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تُطَهَّرَ خَيْرٌ لَهَا ‏"‏ ‏.‏ فَلَمَّا سَمِعْنَا لِينَ قَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَتَيْنَا أُسَامَةَ فَقُلْنَا كَلِّمْ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم ذَلِكَ قَامَ خَطِيبًا فَقَالَ ‏"‏ مَا إِكْثَارُكُمْ عَلَىَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ عَزَّ وَجَلَّ وَقَعَ عَلَى أَمَةٍ مِنْ إِمَاءِ اللَّهِ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ كَانَتْ فَاطِمَةُ ابْنَةُ رَسُولِ اللَّهِ نَزَلَتْ بِالَّذِي نَزَلَتْ بِهِ لَقَطَعَ مُحَمَّدٌ يَدَهَا ‏"‏ ‏.‏\hadithno{2548}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah bin Mas'ud bin Aswad, that her father said:“When the woman stole the Qatifah from the house of the Messenger of Allah (ﷺ), we regarded that as a serious matter. She was a woman from Quraish. So we came to the Prophet (ﷺ) and spoke to him, and said: 'We will ransom her for forty Uqiyyah.' The Messenger of Allah (ﷺ) said: 'Purification is better for her.” When we heard the Messenger of Allah (ﷺ) speak so kindly, we went to Usamah and said: 'Speak to the Messenger of Allah (ﷺ) .' When the Messenger of Allah (ﷺ) saw that, he stood up to speak and said: 'How much do you intercede with me concerning one of the legal punishments of Allah (SWT) that has befallen one of the female slaves of Allah (SWT)! By the One in Whose Hand is the soul of Muhammad, if Fatimah the daughter of the Messenger of Allah (ﷺ) were to do what she has done, Muhammad would cut off her hand.”}}
\hadithdefcmd{ibnmajah}{2549}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، وَشِبْلٍ، قَالُوا كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَاهُ رَجُلٌ فَقَالَ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ فَقَالَ خَصْمُهُ وَكَانَ أَفْقَهَ مِنْهُ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَائْذَنْ لِي حَتَّى أَقُولَ ‏.‏ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا وَإِنَّهُ زَنَى بِامْرَأَتِهِ فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ فَسَأَلْتُ رَجُلاً مِنْ أَهْلِ الْعِلْمِ فَأُخْبِرْتُ أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ وَأَنَّ عَلَى امْرَأَةِ هَذَا الرَّجْمَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ الْمِائَةُ الشَّاةُ وَالْخَادِمُ رَدٌّ عَلَيْكَ وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ وَاغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏ ‏.‏ قَالَ هِشَامٌ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{2549}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah, Zaid bin Khalid and Shibl said:“We were with the Messenger of Allah (ﷺ) and a man came to him and said: 'I adjure you by Allah (SWT) to judge between us according to the Book of Allah (SWT).' His opponent, who was more knowledgeable than him, said: 'Judge between us according to the Book of Allah (SWT), but let me speak first.' He said: 'Speak.' He said: 'My son was a servant of this man, and he committed adultery with his wife, and I ransomed him for one hundred sheep and a servant. I asked some men of knowledge and I was told that my son should be given one hundred lashes and exiled for a year, and that the wife of this man should be stoned.” The Messenger of Allah (ﷺ) said: 'By the One in Whose Hand is my soul, I will judge between you according to the Book of Allah (SWT). The one hundred sheep and the servant are to be returned to you and your son is to be given one hundred lashes and exiled for a year. Go tomorrow, O Unais, to the wife of this man and if she admits I then stone her.'”}}
\hadithdefcmd{ibnmajah}{2550}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا عَنِّي خُذُوا عَنِّي قَدْ جَعَلَ اللَّهُ لَهُنَّ سَبِيلاً الْبِكْرُ بِالْبِكْرِ جَلْدُ مِائَةٍ وَتَغْرِيبُ سَنَةٍ وَالثَّيِّبُ بِالثَّيِّبِ جَلْدُ مِائَةٍ وَالرَّجْمُ ‏"‏ ‏.‏\hadithno{2550}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from `Ubadah bin Samit that the Messenger of Allah (ﷺ) said:“Learn from me. Allah (SWT) has ordained for them (women) another way. (If) a virgin (commits illegal sexual intercourse) with a virgin, (the punishment is) one hundred lashes and exile for one year. (If) a Thayyib (commits adultery) with a Thayyib (the punishment is) one hundred lashes and stoning.”}}
\hadithdefcmd{ibnmajah}{2551}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، أَنْبَأَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، قَالَ أُتِيَ النُّعْمَانُ بْنُ بَشِيرٍ بِرَجُلٍ غَشَى جَارِيَةَ امْرَأَتِهِ فَقَالَ لاَ أَقْضِي فِيهَا إِلاَّ بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ إِنْ كَانَتْ أَحَلَّتْهَا لَهُ جَلَدْتُهُ مِائَةً وَإِنْ لَمْ تَكُنْ أَذِنَتْ لَهُ رَجَمْتُهُ ‏.‏\hadithno{2551}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Habib bin Salim said:“A man who had intercourse with the slave woman of his wife was brought to Nu`man bin Bashir. He said: 'I will pass no other judgement than that of the Messenger of Allah (ﷺ) He said: 'If (his wife) had made her lawful for him, then I will give him one hundred lashes, but if she has not given permission, I will stone him.' ”}}
\hadithdefcmd{ibnmajah}{2552}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ سَلَمَةَ بْنِ الْمُحَبِّقِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رُفِعَ إِلَيْهِ رَجُلٌ وَطِئَ جَارِيَةَ امْرَأَتِهِ فَلَمْ يَحُدَّهُ ‏.‏\hadithno{2552}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salamah bin Muhabbiq that:the case of a man who had intercourse with the slave woman of his wife was referred to the Messenger of Allah (ﷺ), and he did not stipulate any legal punishment for him}}
\hadithdefcmd{ibnmajah}{2553}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ لَقَدْ خَشِيتُ أَنْ يَطُولَ، بِالنَّاسِ زَمَانٌ حَتَّى يَقُولَ قَائِلٌ مَا أَجِدُ الرَّجْمَ فِي كِتَابِ اللَّهِ فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ مِنْ فَرَائِضِ اللَّهِ أَلاَ وَإِنَّ الرَّجْمَ حَقٌّ إِذَا أُحْصِنَ الرَّجُلُ وَقَامَتِ الْبَيِّنَةُ أَوْ كَانَ حَمْلٌ أَوِ اعْتِرَافٌ وَقَدْ قَرَأْتُهَا الشَّيْخُ وَالشَّيْخَةُ إِذَا زَنَيَا فَارْجُمُوهُمَا الْبَتَّةَ ‏.‏ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا بَعْدَهُ ‏.‏\hadithno{2553}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn`Abbas that `Umar bin Khattab said:“I fear that after a long time has passed, some will say: 'I do not find (the sentence of) stoning in the Book of Allah (ﷺ),' and they will go astray by abandoning one of the obligations enjoined by Allah (SWT). Rather stoning is a must if a man is married (or previously married) and proof is established, or if pregnancy results or if he admits it. I have read it (in the Quran). “And if an old man and an old woman commit adultery, stone them both.” The Messenger of Allah (ﷺ) stoned (adulterers) and we stoned (them) after him.' ”}}
\hadithdefcmd{ibnmajah}{2554}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ مَاعِزُ بْنُ مَالِكٍ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقَالَ إِنِّي قَدْ زَنَيْتُ ‏.‏ فَأَعْرَضَ عَنْهُ ثُمَّ قَالَ إِنِّي قَدْ زَنَيْتُ فَأَعْرَضَ عَنْهُ ‏.‏ ثُمَّ قَالَ إِنِّي زَنَيْتُ ‏.‏ فَأَعْرَضَ عَنْهُ ‏.‏ ثُمَّ قَالَ قَدْ زَنَيْتُ ‏.‏ فَأَعْرَضَ عَنْهُ حَتَّى أَقَرَّ أَرْبَعَ مَرَّاتٍ فَأَمَرَ بِهِ أَنْ يُرْجَمَ ‏.‏ فَلَمَّا أَصَابَتْهُ الْحِجَارَةُ أَدْبَرَ يَشْتَدُّ فَلَقِيَهُ رَجُلٌ بِيَدِهِ لَحْىُ جَمَلٍ فَضَرَبَهُ فَصَرَعَهُ فَذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم فِرَارُهُ حِينَ مَسَّتْهُ الْحِجَارَةُ قَالَ ‏ "‏ فَهَلاَّ تَرَكْتُمُوهُ ‏"‏ ‏.‏\hadithno{2554}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“Ma`iz bin Malik came to the Prophet (ﷺ) and said: 'I have committed fornication,' and he (the Prophet (ﷺ)) turned away from him. He said: 'I have committed fornication,' and he turned away from him. Then, he said: I have committed fornication, and he turned away from him, until when he had confessed four times, he ordered that he should be stoned. When he was being struck with the stones, he ran away, but a man caught up with him who had a camel's jawbone in his hand; he struck him and he fell down. The Prophet (ﷺ) was told about how he fled when the stones hit him and he said: 'Why did you not let him be?'”}}
\hadithdefcmd{ibnmajah}{2555}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَمْرٍو، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَاجِرِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَاعْتَرَفَتْ بِالزِّنَا فَأَمَرَ بِهَا فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ثُمَّ رَجَمَهَا ثُمَّ صَلَّى عَلَيْهَا ‏.‏\hadithno{2555}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from `Imran bin Husain that :a woman came to the Prophet (ﷺ) and confessed to committing fornication. He issued orders, and her garments were tightened around her (so that her private parts would not become uncovered) then he stoned her, then he offered the funeral prayer for her}}
\hadithdefcmd{ibnmajah}{2556}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَجَمَ يَهُودِيَّيْنِ أَنَا فِيمَنْ رَجَمَهُمَا فَلَقَدْ رَأَيْتُهُ وَإِنَّهُ يَسْتُرُهَا مِنَ الْحِجَارَةِ ‏.‏\hadithno{2556}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn`Umar:The Prophet (ﷺ) stoned two Jews, and I was among those who stoned them. I saw (the man) trying to shield (the woman) from the stones.”}}
\hadithdefcmd{ibnmajah}{2557}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَجَمَ يَهُودِيًّا وَيَهُودِيَّةً ‏.‏\hadithno{2557}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin Samurah that :the Prophet (ﷺ) stoned a Jewish man and a Jewish woman}}
\hadithdefcmd{ibnmajah}{2558}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ مَرَّ النَّبِيُّ بِيَهُودِيٍّ مُحَمَّمٍ مَجْلُودٍ فَدَعَاهُمْ فَقَالَ ‏"‏ هَكَذَا تَجِدُونَ فِي كِتَابِكُمْ حَدَّ الزَّانِي ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَدَعَا رَجُلاً مِنْ عُلَمَائِهِمْ فَقَالَ ‏"‏ أَنْشُدُكَ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى أَهَكَذَا تَجِدُونَ حَدَّ الزَّانِي قَالَ لاَ وَلَوْلاَ أَنَّكَ نَشَدْتَنِي لَمْ أُخْبِرْكَ نَجِدُ حَدَّ الزَّانِي فِي كِتَابِنَا الرَّجْمَ وَلَكِنَّهُ كَثُرَ فِي أَشْرَافِنَا فَكُنَّا إِذَا أَخَذْنَا الشَّرِيفَ تَرَكْنَاهُ وَكُنَّا إِذَا أَخَذْنَا الضَّعِيفَ أَقَمْنَا عَلَيْهِ الْحَدَّ ‏.‏ فَقُلْنَا تَعَالَوْا فَلْنَجْتَمِعْ عَلَى شَىْءٍ نُقِيمُهُ عَلَى الشَّرِيفِ وَالْوَضِيعِ فَاجْتَمَعْنَا عَلَى التَّحْمِيمِ وَالْجَلْدِ مَكَانَ الرَّجْمِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم اللَّهُمَّ إِنِّي أَوَّلُ مَنْ أَحْيَا أَمْرَكَ إِذْ أَمَاتُوهُ ‏"‏ ‏.‏ وَأَمَرَ بِهِ فَرُجِمَ ‏.‏\hadithno{2558}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bara' bin Azib said:“The Messenger of Allah (ﷺ) passed by a Jew with a blackened face who had been flogged. He called them and said: 'Is this the punishment for the adulterer that you find in your Book?' They said: 'Yes.' Then he called one of their scholars and said: 'I adjure you by Allah (SWT) Who sent down the Tawrah (Torah) to Musa! Is this the punishment for the adulterer that you find in your Book?' He said: 'No; if you had not adjured me by Allah (SWT), I would not have told you. The punishment for the adulterer that we find in our Book is stoning, but many of our nobles were being stoned (because of the prevalence of adultery among them), so if we caught one of our nobles (committing adultery), we would let him go; but if we caught one of the weak among us, we would carry out the punishment on him. We said: “Come, let us agree upon something that we may impose on both noble and weak alike.” So we agreed to blacken the face and whip them, instead of stoning.' The Prophet (ﷺ) 'O Allah (SWT), I am the first of those who revive your command which they had killed off,' and he issued orders that (the man) be stoned.”}}
\hadithdefcmd{ibnmajah}{2559}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا زَيْدُ بْنُ يَحْيَى بْنِ عُبَيْدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ رَاجِمًا أَحَدًا بِغَيْرِ بَيِّنَةٍ لَرَجَمْتُ فُلاَنَةَ فَقَدْ ظَهَرَ فِيهَا الرِّيبَةُ فِي مَنْطِقِهَا وَهَيْئَتِهَا وَمَنْ يَدْخُلُ عَلَيْهَا ‏"‏ ‏.‏\hadithno{2559}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“If I were to stone anyone without proof, I would have stoned so-and-so, for there is obviously doubt concerning her speech, her appearance and those who enter upon her.”}}
\hadithdefcmd{ibnmajah}{2560}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ ذَكَرَ ابْنُ عَبَّاسٍ الْمُتَلاَعِنَيْنِ ‏.‏ فَقَالَ لَهُ ابْنُ شَدَّادٍ هِيَ الَّتِي قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ رَاجِمًا أَحَدًا بِغَيْرِ بَيِّنَةٍ لَرَجَمْتُهَا ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ تِلْكَ امْرَأَةٌ أَعْلَنَتْ ‏.‏\hadithno{2560}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Qasim bin Muhammad said:“Ibn `Abbas mentioned two people who had engaged in the process of Li`an. Ibn Shaddad said to him: 'Is this the one of whom the Messenger of Allah (ﷺ) said: “If I were to stone anyone without proof I would have stoned so-and-so.” Ibn`Abbas said: 'No, that was a woman who, (although she was a Muslim), used to expose herself.'”}}
\hadithdefcmd{ibnmajah}{2561}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ وَجَدْتُمُوهُ يَعْمَلُ عَمَلَ قَوْمِ لُوطٍ فَاقْتُلُوا الْفَاعِلَ وَالْمَفْعُولَ بِهِ ‏"‏ ‏.‏\hadithno{2561}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“Whoever you find doing the action of the people of Lut, kill the one who does it, and the one to whom it is done.”}}
\hadithdefcmd{ibnmajah}{2562}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ نَافِعٍ، أَخْبَرَنِي عَاصِمُ بْنُ عُمَرَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يَعْمَلُ عَمَلَ قَوْمِ لُوطٍ قَالَ ‏ "‏ ارْجُمُوا الأَعْلَى وَالأَسْفَلَ ارْجُمُوهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{2562}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said concerning those who do the action of the people of Lut:“Stone the upper and the lower, stone them both.”}}
\hadithdefcmd{ibnmajah}{2563}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا الْقَاسِمُ بْنُ عَبْدِ الْوَاحِدِ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخْوَفَ مَا أَخَافُ عَلَى أُمَّتِي عَمَلُ قَوْمِ لُوطٍ ‏"‏ ‏.‏\hadithno{2563}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin`Abdullah that the Messenger of Allah (ﷺ) said:“The thing that I most fear for my nation is the action of the people of Lut.”}}
\hadithdefcmd{ibnmajah}{2564}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ إِبْرَاهِيمَ بْنِ إِسْمَاعِيلَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَقَعَ عَلَى ذَاتِ مَحْرَمٍ فَاقْتُلُوهُ وَمَنْ وَقَعَ عَلَى بَهِيمَةٍ فَاقْتُلُوهُ وَاقْتُلُوا الْبَهِيمَةَ ‏"‏ ‏.‏\hadithno{2564}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“Whoever has intercourse with a Mahram relative, kill him; and whoever has intercourse with an animal, kill him, and kill the animal.”}}
\hadithdefcmd{ibnmajah}{2565}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، وَشِبْلٍ، قَالُوا كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ رَجُلٌ عَنِ الأَمَةِ تَزْنِي قَبْلَ أَنْ تُحْصَنَ ‏.‏ فَقَالَ ‏"‏ اجْلِدْهَا فَإِنْ زَنَتْ فَاجْلِدْهَا فَإِنْ زَنَتْ فَاجْلِدْهَا ‏"‏ ‏.‏ ثُمَّ قَالَ فِي الثَّالِثَةِ أَوْ فِي الرَّابِعَةِ ‏"‏ فَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏ ‏.‏\hadithno{2565}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah, Zaid bin Khalid and Shibl said:“We were with the Prophet (ﷺ) and a man asked him about a slave woman who commits fornication (again), whip her, even if that is for a rope of hair.' ”}}
\hadithdefcmd{ibnmajah}{2566}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَمَّارِ بْنِ أَبِي فَرْوَةَ، أَنَّ مُحَمَّدَ بْنَ مُسْلِمٍ، حَدَّثَهُ أَنَّ عُرْوَةَ حَدَّثَهُ أَنَّ عَمْرَةَ بِنْتَ عَبْدِ الرَّحْمَنِ حَدَّثَتْهُ أَنَّ عَائِشَةَ حَدَّثَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَنَتِ الأَمَةُ فَاجْلِدُوهَا فَإِنْ زَنَتْ فَاجْلِدُوهَا فَإِنْ زَنَتْ فَاجْلِدُوهَا فَإِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏ ‏.‏ وَالضَّفِيرُ الْحَبْلُ ‏.‏\hadithno{2566}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that the Messenger of Allah(ﷺ) said:“If a slave woman commits fornication then whip her, and if she commits fornication then whip her, and if she commits fornication then whip her, then sell her even if that is for a rope.”}}
\hadithdefcmd{ibnmajah}{2567}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَ عُذْرِي قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَذَكَرَ ذَلِكَ وَتَلاَ الْقُرْآنَ فَلَمَّا نَزَلَ أَمَرَ بِرَجُلَيْنِ وَامْرَأَةٍ فَضُرِبُوا حَدَّهُمْ ‏.‏\hadithno{2567}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:“When my innocence was revealed, the Messenger of Allah (ﷺ) stood on the pulpit and mentioned that, and he recited Quran. When he came down, he ordered that the legal punishment (of slandering) be carried out on two men and a woman.”}}
\hadithdefcmd{ibnmajah}{2568}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي ابْنُ أَبِي حَبِيبَةَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الرَّجُلُ لِلرَّجُلِ يَا مُخَنَّثُ فَاجْلِدُوهُ عِشْرِينَ وَإِذَا قَالَ الرَّجُلُ لِلرَّجُلِ يَا لُوطِيُّ فَاجْلِدُوهُ عِشْرِينَ ‏"‏ ‏.‏\hadithno{2568}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Abbas that the Prophet (ﷺ) said:“If one man says another: 'O effeminate one!' give him twenty lashes. And if one man says to another: 'O homosexual!' give him twenty twenty lashes.”}}
\hadithdefcmd{ibnmajah}{2569}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي حُصَيْنٍ، عَنْ عُمَيْرِ بْنِ سَعِيدٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا مُطَرِّفٌ، سَمِعْتُهُ عَنْ عُمَيْرِ بْنِ سَعِيدٍ، قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ مَا كُنْتُ أَدِي مَنْ أَقَمْتُ عَلَيْهِ الْحَدَّ إِلاَّ شَارِبَ الْخَمْرِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسُنَّ فِيهِ شَيْئًا إِنَّمَا هُوَ شَىْءٌ جَعَلْنَاهُ نَحْنُ ‏.‏\hadithno{2569}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ali bin Abi Talib said:“I would not pay the blood money (Diyah) for those on whom I carried out the legal punishment, except for the wine-drinker. The Messenger of Allah did not institute anything in that case, rather it is something that we would do.”}}
\hadithdefcmd{ibnmajah}{2570}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، جَمِيعًا عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضْرِبُ فِي الْخَمْرِ بِالنِّعَالِ وَالْجَرِيدِ ‏.‏\hadithno{2570}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) used to beat (offenders) for drinking wine with sandals and date-palm stalks.”}}
\hadithdefcmd{ibnmajah}{2571}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّانَاجِ، سَمِعْتُ حُضَيْنَ بْنَ الْمُنْذِرِ الرَّقَاشِيَّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ فَيْرُوزَ الدَّانَاجُ، قَالَ حَدَّثَنِي حُضَيْنُ بْنُ الْمُنْذِرِ، قَالَ لَمَّا جِيءَ بِالْوَلِيدِ بْنِ عُقْبَةَ إِلَى عُثْمَانَ قَدْ شَهِدُوا عَلَيْهِ قَالَ لِعَلِيٍّ دُونَكَ ابْنَ عَمِّكَ فَأَقِمْ عَلَيْهِ الْحَدَّ ‏.‏ فَجَلَدَهُ عَلِيٌّ وَقَالَ جَلَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْبَعِينَ وَجَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ وَجَلَدَ عُمَرُ ثَمَانِينَ وَكُلٌّ سُنَّةٌ ‏.‏\hadithno{2571}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Hudain bin Mundhir said:“When Walid bin `Uqbah was brought to `Uthman, they had testified against him. He said to 'Ali: 'You are close to your uncle's son, so carry out the legal punishment on him.' So 'Ali whipped him. He said: 'The Messenger of Allah (ﷺ) gave forty lashes, and Abu Bakr gave forty lashes, and 'Umar gave eighty all are Sunnah.'”}}
\hadithdefcmd{ibnmajah}{2572}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْحَارِثِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا سَكِرَ فَاجْلِدُوهُ فَإِنْ عَادَ فَاجْلِدُوهُ فَإِنْ عَادَ فَاجْلِدُوهُ ‏"‏ ‏.‏ ثُمَّ قَالَ فِي الرَّابِعَةِ ‏"‏ فَإِنْ عَادَ فَاضْرِبُوا عُنُقَهُ ‏"‏ ‏.‏\hadithno{2572}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“If he gets drunk, then whip him. If he does it again, then whip him. If he does it again, then whip him.' And he said concerning the fourth time: 'If he does it again, then strike his neck (i.e., execute him).' ”}}
\hadithdefcmd{ibnmajah}{2573}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ ذَكْوَانَ أَبِي صَالِحٍ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبُوا الْخَمْرَ فَاجْلِدُوهُمْ ثُمَّ إِذَا شَرِبُوا فَاجْلِدُوهُمْ ثُمَّ إِذَا شَرِبُوا فَاجْلِدُوهُمْ ثُمَّ إِذَا شَرِبُوا فَاقْتُلُوهُمْ ‏"‏ ‏.‏\hadithno{2573}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Mu`awiyah bin Abu Sufyan that the Messenger of Allah (ﷺ) said:“If they drink (again), then whip them. If they drink (again), then whip them. If they drink (again), then whip them. If they drink (again), then kill them.”}}
\hadithdefcmd{ibnmajah}{2574}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ سَعِيدِ بْنِ سَعْدِ بْنِ عُبَادَةَ، قَالَ كَانَ بَيْنَ أَبْيَاتِنَا رَجُلٌ مُخْدَجٌ ضَعِيفٌ فَلَمْ يُرَعْ إِلاَّ وَهُوَ عَلَى أَمَةٍ مِنْ إِمَاءِ الدَّارِ يَخْبُثُ بِهَا فَرَفَعَ شَأْنَهُ سَعْدُ بْنُ عُبَادَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ اجْلِدُوهُ ضَرْبَ مِائَةِ سَوْطٍ ‏"‏ ‏.‏ قَالُوا يَا نَبِيَّ اللَّهِ هُوَ أَضْعَفُ مِنْ ذَلِكَ لَوْ ضَرَبْنَاهُ مِائَةَ سَوْطٍ مَاتَ ‏.‏ قَالَ ‏"‏ فَخُذُوا لَهُ عِثْكَالاً فِيهِ مِائَةُ شِمْرَاخٍ فَاضْرِبُوهُ ضَرْبَةً وَاحِدَةً ‏"‏ ‏.‏ حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2574}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'eed bin Sa'd bin `Ubadah said:“There was a man living among our dwellings who had a physical defect, and to our astonishment he was seen with one of the slave women of the dwellings, committing illegal sex with her. Sa'd bin 'Ubadah referred his case to the Messenger of Allah (ﷺ), who said: 'Give him one hundred lashes.' They said: 'O Prophet (ﷺ) of Allah (ﷺ), he is too weak to bear that. If we give him one hundred lashes he will die.' He said: “Then take a branch with a hundred twigs and hit him once.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2575}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ وَحَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ وَحَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ أَبِي مَعْشَرٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، وَمُوسَى بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{2575}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever bears weapons against us is not one of us.”}}
\hadithdefcmd{ibnmajah}{2576}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ الْبَرَّادِ بْنِ يُوسُفَ بْنِ بُرَيْدِ بْنِ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{2576}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn `Umar that the Messenger of Allah (ﷺ) said:“Whoever bears weapons against us is not one of us.'”}}
\hadithdefcmd{ibnmajah}{2577}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَأَبُو كُرَيْبٍ وَيُوسُفُ بْنُ مُوسَى وَعَبْدُ اللَّهِ بْنُ الْبَرَّادِ قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَهَرَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{2577}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that the Messenger of Allah (ﷺ) said:“Whoever brandishes weapons against us is not one of us.'”}}
\hadithdefcmd{ibnmajah}{2578}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أُنَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَقَالَ ‏ "‏ لَوْ خَرَجْتُمْ إِلَى ذَوْدٍ لَنَا فَشَرِبْتُمْ مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ فَفَعَلُوا فَارْتَدُّوا عَنِ الإِسْلاَمِ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوا ذَوْدَهُ فَبَعَثَ رَسُولُ اللَّهِ فِي طَلَبِهِمْ فَجِيءَ بِهِمْ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَرَ أَعْيُنَهُمْ وَتَرَكَهُمْ بِالْحَرَّةِ حَتَّى مَاتُوا ‏.‏\hadithno{2578}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that :some people from (the tribe of) `Urainah came to us (to Al-Madinah) during the time of the Messenger of Allah (ﷺ), but they did not want to stay in Al-Madinah because the climate did not suit them. He said: “Go out to the camels which belong to us, and drink their milk and urine.” So they did that (and recovered), then they apostatized from Islam and killed the herdsman of the Messenger of Allah (ﷺ) and stole his camels. The Messenger of Allah (ﷺ) sent people after them, and they were brought back. Then he cut off their hands and feet, branded their eyes and left them in Harrah until they died}}
\hadithdefcmd{ibnmajah}{2579}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، حَدَّثَنَا الدَّرَاوَرْدِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ قَوْمًا، أَغَارُوا عَلَى لِقَاحِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَطَعَ النَّبِيُّ صلى الله عليه وسلم أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{2579}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that :some people raided the she-camels of the Messenger of Allah (ﷺ) , so the Prophet(ﷺ) cut off their hands and feet (on opposite sides) and lanced (gouged out) their eyes}}
\hadithdefcmd{ibnmajah}{2580}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{2580}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'eed bin Zaid bin 'Amr bin Nufail that the Prophet (ﷺ) said:“Whoever is killed defending his property, he is a martyr.”}}
\hadithdefcmd{ibnmajah}{2581}{حَدَّثَنَا الْخَلِيلُ بْنُ عَمْرٍو، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا يَزِيدُ بْنُ سِنَانٍ الْجَزَرِيُّ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُتِيَ عِنْدَ مَالِهِ فُقُوتِلَ فَقَاتَلَ فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{2581}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn `Umar that the Messenger of Allah (ﷺ) said:“If a man's property is targeted, and he is fought and fights back and is killed, he is a martyr.”}}
\hadithdefcmd{ibnmajah}{2582}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُطَّلِبِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُرِيدَ مَالُهُ ظُلْمًا فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{2582}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: 'If a man's property is wrongfully targeted, and he is killed, he is a martyr.”}}
\hadithdefcmd{ibnmajah}{2583}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ السَّارِقَ يَسْرِقُ الْبَيْضَةَ فَتُقْطَعُ يَدُهُ وَيَسْرِقُ الْحَبْلَ فَتُقْطَعُ يَدُهُ ‏"‏ ‏.‏\hadithno{2583}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (S.A.W.) said:“May Allah curse the thief! He steals an egg and his hand is cut off, and he steals a rope and his hand is cut off”}}
\hadithdefcmd{ibnmajah}{2584}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بَنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَطَعَ النَّبِيُّ صلى الله عليه وسلم فِي مِجَنٍّ قِيمَتُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{2584}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Umar said:“The Prophet (S.A.W.) cut off (the hand of a thief) for a shield worth three Dirham.”}}
\hadithdefcmd{ibnmajah}{2585}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَمْرَةَ، أَخْبَرَتْهُ عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{2585}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that the Messenger of Allah (S.A.W.) said:“Do not cut off (the thief's hand) except for something worth one quarter of a Dinar or more}}
\hadithdefcmd{ibnmajah}{2586}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَبُو وَاقِدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي ثَمَنِ الْمِجَنِّ ‏"‏ ‏.‏\hadithno{2586}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Amir bin Sa'd, from this father, that the Prophet (ﷺ) said:“The hand of the thief is to be cut off for the price of a shield}}
\hadithdefcmd{ibnmajah}{2587}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو بِشْرٍ بَكْرُ بْنُ خَلَفٍ وَمُحَمَّدُ بْنُ بَشَّارٍ وَأَبُو سَلَمَةَ الْجُوبَارِيُّ يَحْيَى بْنُ خَلَفٍ قَالُوا حَدَّثَنَا عُمَرُ بْنُ عَلِيِّ بْنِ عَطَاءِ بْنِ مُقَدَّمٍ، عَنْ حَجَّاجٍ، عَنْ مَكْحُولٍ، عَنِ ابْنِ مُحَيْرِيزٍ، قَالَ سَأَلْتُ فَضَالَةَ بْنَ عُبَيْدٍ عَنْ تَعْلِيقِ الْيَدِ، فِي الْعُنُقِ فَقَالَ السُّنَّةُ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَ رَجُلٍ ثُمَّ عَلَّقَهَا فِي عُنُقِهِ ‏.‏\hadithno{2587}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Muhairiz said:“I asked Fadalah bin Ubaid about hanging the hand (of the thief) from this neck, and he said: 'It is sunnah. The messenger of Allah (ﷺ) cut off a man's hand then hung it from his neck}}
\hadithdefcmd{ibnmajah}{2588}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَعْلَبَةَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّ عَمْرَو بْنَ سَمُرَةَ بْنِ حَبِيبِ بْنِ عَبْدِ شَمْسٍ، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي سَرَقْتُ جَمَلاً لِبَنِي فُلاَنٍ فَطَهِّرْنِي ‏.‏ فَأَرْسَلَ إِلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم فَقَالُوا إِنَّا افْتَقَدْنَا جَمَلاً لَنَا فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَقُطِعَتْ يَدُهُ ‏.‏ قَالَ ثَعْلَبَةُ أَنَا أَنْظُرُ إِلَيْهِ حِينَ وَقَعَتْ يَدُهُ وَهُوَ يَقُولُ الْحَمْدُ لِلَّهِ الَّذِي طَهَّرَنِي مِنْكِ أَرَدْتِ أَنْ تُدْخِلِي جَسَدِي النَّارَ ‏.‏\hadithno{2588}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdur-Rahman bin Tha’labah Al-Ansari, from his father, that Amr bin Samurah bin Habib bin Abd Shams came to the Messenger of Allah (ﷺ) and said:“O Messenger of Allah (ﷺ)! I stole a camel belonging to Banu so-and-so; purify me!” The Prophet (ﷺ) sent word to them and they said: “(Yes), we have lost a camel of ours.” So the Prophet (ﷺ) ordered that his hand be cut off. Tha'labah said: “I was looking at him when his hand fell and he said (to it) 'Praise is to Allah (STW) Who has purified me of you; you wanted to cause my whole body to enter Hell}}
\hadithdefcmd{ibnmajah}{2589}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَرَقَ الْعَبْدُ فَبِيعُوهُ وَلَوْ بِنَشٍّ ‏"‏ ‏.‏\hadithno{2589}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated Abu Hurairah that the Messenger of Allah (ﷺ) said:“If a slave steals, then sell him, even for half Price.' ”}}
\hadithdefcmd{ibnmajah}{2590}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا حَجَّاجُ بْنُ تَمِيمٍ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ عَبْدًا، مِنْ رَقِيقِ الْخُمُسِ سَرَقَ مِنَ الْخُمُسِ فَرُفِعَ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَقْطَعْهُ وَقَالَ ‏ "‏ مَالُ اللَّهِ عَزَّ وَجَلَّ سَرَقَ بَعْضُهُ بَعْضًا ‏"‏ ‏.‏\hadithno{2590}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Abbas that :one of the slaves of Khumus stole something from the Khumus, and the matter was referred to the Prophet (ﷺ) but he did not cut off his hand, and he said ' The Property of Allah, (STW) part of it stealing another part.' ”}}
\hadithdefcmd{ibnmajah}{2591}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقْطَعُ الْخَائِنُ وَلاَ الْمُنْتَهِبُ وَلاَ الْمُخْتَلِسُ ‏"‏ ‏.‏\hadithno{2591}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin Abdullah that the Messenger of Allah (ﷺ) said:“The hand of the one who betrays a trust, the robber and the pilferer is not to be cut off”}}
\hadithdefcmd{ibnmajah}{2592}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَاصِمِ بْنِ جَعْفَرٍ الْمِصْرِيُّ، حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ عَلَى الْمُخْتَلِسِ قَطْعٌ ‏"‏ ‏.‏\hadithno{2592}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibrahim bin Abdur-Rahman bin Awf that his father said:“I heard the Messenger of Allah (ﷺ) say: 'The hand of the pilferer is not to be cut off”}}
\hadithdefcmd{ibnmajah}{2593}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{2593}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Rafi bin Khadij that the Messenger of Allah (ﷺ) said:“The hand is not to be cut off for (stealing) produce or the spadix of palm trees.”}}
\hadithdefcmd{ibnmajah}{2594}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَخِيهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{2594}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The hand is not to be cut off for (stealing) produce or the spadix of palm trees.”}}
\hadithdefcmd{ibnmajah}{2595}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، عَنْ أَبِيهِ، أَنَّهُ نَامَ فِي الْمَسْجِدِ وَتَوَسَّدَ رِدَاءَهُ فَأُخِذَ مِنْ تَحْتِ رَأْسِهِ فَجَاءَ بِسَارِقِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقْطَعَ فَقَالَ صَفْوَانُ يَا رَسُولَ اللَّهِ لَمْ أُرِدْ هَذَا رِدَائِي عَلَيْهِ صَدَقَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَهَلاَّ قَبْلَ أَنْ تَأْتِيَنِي بِهِ ‏"‏ ‏.‏\hadithno{2595}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abdullah bin Safwan that :his father slept in the mosque, using his upper wrap as a pillow, and it was taken from beneath his head. He brought the thief to the Prophet (ﷺ) and the Prophet (ﷺ) ordered that his hand be cut off. Safwan said: “O Messenger of Allah , (ﷺ) I did not want this! I give my upper wrap to him in charity.” The Messenger of Allah (ﷺ) said: “Why did you not give it to him before you brought him to me?”}}
\hadithdefcmd{ibnmajah}{2596}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، مِنْ مُزَيْنَةَ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الثِّمَارِ فَقَالَ ‏"‏ مَا أُخِذَ فِي أَكْمَامِهِ فَاحْتُمِلَ فَثَمَنُهُ وَمِثْلُهُ مَعَهُ وَمَا كَانَ فِي الْجِرَانِ فَفِيهِ الْقَطْعُ إِذَا بَلَغَ ذَلِكَ ثَمَنَ الْمِجَنِّ وَإِنْ أَكَلَ وَلَمْ يَأْخُذْ فَلَيْسَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ الشَّاةُ الْحَرِيسَةُ مِنْهُنَّ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثَمَنُهَا وَمِثْلُهُ مَعَهُ وَالنَّكَالُ وَمَا كَانَ فِي الْمُرَاحِ فَفِيهِ الْقَطْعُ إِذَا كَانَ مَا يَأْخُذُ مِنْ ذَلِكَ ثَمَنَ الْمِجَنِّ ‏"‏ ‏.‏\hadithno{2596}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{XOIt was narrated from Amr bin Shu'aib, from his father, from his grandfather, that a man from Muzainah asked the Prophet (ﷺ) about fruits. :He said: “What is taken from the tree and carried away, its value and the like of it along with it (meaning double its price must be paid). What (is taken) from the place where dates are dried, (the penalty) is cutting off the hand if the amount taken is equal to the price of a shield. But if (the person) eats it and does not take it away, there is no penalty.” He said: “What about the sheep taken from the pasture, O Messenger of Allah (ﷺ)?” He said: “(The thief) must pay double its price and be punished, and if it was in the pen then his hand should be cut off, if what was taken was worth the price of a shield.”}}
\hadithdefcmd{ibnmajah}{2597}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ أَبِي طَلْحَةَ، سَمِعْتُ أَبَا الْمُنْذِرِ، - مَوْلَى أَبِي ذَرٍّ - يَذْكُرُ أَنَّ أَبَا أُمَيَّةَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلِصٍّ فَاعْتَرَفَ اعْتِرَافًا وَلَمْ يُوجَدْ مَعَهُ الْمَتَاعُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا إِخَالُكَ سَرَقْتَ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ ثُمَّ قَالَ ‏"‏ مَا إِخَالُكَ سَرَقْتَ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ فَأَمَرَ بِهِ فَقُطِعَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُلْ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ تُبْ عَلَيْهِ ‏"‏ ‏.‏ مَرَّتَيْنِ ‏.‏\hadithno{2597}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ishaq bin Abu Talhah:“I heard Abu Mundhir, the freed slave of Abu Dharr, say that Abu Umayyah narrated to him, that a thief was brought to the Messenger of Allah (ﷺ) and he admitted his crime, although the stolen goods were not found with him. The Messenger of Allah (ﷺ) said: 'I do not think you stole them.’ He said: 'Yes I did.' Then he said (again): ‘I do not think that you stole them.’ and he said: 'Yes I did.' Then he ordered that his hand be cut off. The Prophet (ﷺ) ' Say: I seek Allah's forgiveness and I repent to Him.' So he (the thief) said: 'I seek Allah's forgiveness and I repent to him.' He (the Prophet (ﷺ) said twice: 'O Allah! Accept his repentance.”}}
\hadithdefcmd{ibnmajah}{2598}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، وَأَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا مُعَمَّرُ بْنُ سُلَيْمَانَ، أَنْبَأَنَا الْحَجَّاجُ بْنُ أَرْطَاةَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ اسْتُكْرِهَتِ امْرَأَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَرَأَ عَنْهَا الْحَدَّ وَأَقَامَهُ عَلَى الَّذِي أَصَابَهَا ‏.‏ وَلَمْ يَذْكُرْ أَنَّهُ جَعَلَ لَهَا مَهْرًا ‏.‏\hadithno{2598}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdul Jabbar bin Wa'il that his father said:“A Woman was coerced (i.e., raped) during the time of Messenger of Allah (ﷺ) He waived the legal punishment for her and carried it out on the one who had attacked her, but he (the narrator) did not say that he rules that she should be given a bridal-money.”}}
\hadithdefcmd{ibnmajah}{2599}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا أَبُو حَفْصٍ الأَبَّارُ، جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقَامُ الْحُدُودُ فِي الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{2599}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Abbas that the Messenger of Allah (ﷺ) said:“Do not carry out the legal punishment in the mosque.”}}
\hadithdefcmd{ibnmajah}{2600}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ لَهِيعَةَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، أَنَّهُ سَمِعَ عَمْرَو بْنَ شُعَيْبٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ جَلْدِ الْحَدِّ فِي الْمَسَاجِدِ ‏.‏\hadithno{2600}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that:the Messenger of Allah (ﷺ) forbade lashing for the legal punishment in the mosques}}
\hadithdefcmd{ibnmajah}{2601}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ بْنِ نِيَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لاَ يُجْلَدُ أَحَدٌ فَوْقَ عَشْرِ جَلَدَاتٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏\hadithno{2601}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Burdah bin Niyar that the Messenger of Allah (ﷺ) used to say:“No one should be given more than ten lashes, except in the case of one of the legal punishments of Allah (SWT).”}}
\hadithdefcmd{ibnmajah}{2602}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا عَبَّادُ بْنُ كَثِيرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُعَزِّرُوا فَوْقَ عَشَرَةِ أَسْوَاطٍ ‏"‏ ‏.‏\hadithno{2602}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Do not punish with more than ten whips.”}}
\hadithdefcmd{ibnmajah}{2603}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، وَابْنُ أَبِي عَدِيٍّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَصَابَ مِنْكُمْ حَدًّا فَعُجِّلَتْ لَهُ عُقُوبَتُهُ فَهُوَ كَفَّارَتُهُ وَإِلاَّ فَأَمْرُهُ إِلَى اللَّهِ ‏"‏ ‏.‏\hadithno{2603}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ubadah bin Samit that the Messenger of Allah (ﷺ) said:“Whoever among you undergoes a Hadd, his punishment has been brought forward, and it is an expiation for him otherwise his case rests with Allah.”}}
\hadithdefcmd{ibnmajah}{2604}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جُحَيْفَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَصَابَ فِي الدُّنْيَا ذَنْبًا فَعُوقِبَ بِهِ فَاللَّهُ أَعْدَلُ مِنْ أَنْ يُثَنِّيَ عُقُوبَتَهُ عَلَى عَبْدِهِ وَمَنْ أَذْنَبَ ذَنْبًا فِي الدُّنْيَا فَسَتَرَهُ اللَّهُ عَلَيْهِ فَاللَّهُ أَكْرَمُ مِنْ أَنْ يَعُودَ فِي شَىْءٍ قَدْ عَفَا عَنْهُ ‏"‏ ‏.‏\hadithno{2604}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ali that the Messenger of Allah (ﷺ) said:“Whoever commits a sin in this world and is punished for it, Allah (STW) is too just to repeat the punishment for his slave (in the hereafter). And whoever commits a sin in this world and Allah conceals him, Allah is too generous to go back to something that He has pardoned.”}}
\hadithdefcmd{ibnmajah}{2605}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَمُحَمَّدُ بْنُ عُبَيْدٍ الْمَدِينِيُّ أَبُو عُبَيْدٍ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ الأَنْصَارِيَّ، قَالَ يَا رَسُولَ اللَّهِ الرَّجُلُ يَجِدُ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ سَعْدٌ بَلَى وَالَّذِي أَكْرَمَكَ بِالْحَقِّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْمَعُوا مَا يَقُولُ سَيِّدُكُمْ ‏"‏ ‏.‏\hadithno{2605}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that Sa'd bin Ubadah Al-Ansari said:“O Messenger of Allah (ﷺ) if a man finds another man with his wife, should he kill him?” The Messenger of Allah (ﷺ) said: “No.” Sa'd said: “Yes he should, by the one who honored you with the Truth!” The Messenger of Allah (ﷺ) said: “Listen to what your leader says!”}}
\hadithdefcmd{ibnmajah}{2606}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْفَضْلِ بْنِ دَلْهَمٍ، عَنِ الْحَسَنِ، عَنْ قَبِيصَةَ بْنِ حُرَيْثٍ، عَنْ سَلَمَةَ بْنِ الْمُحَبِّقِ، قَالَ قِيلَ لأَبِي ثَابِتٍ سَعْدِ بْنِ عُبَادَةَ حِينَ نَزَلَتْ آيَةُ الْحُدُودِ وَكَانَ رَجُلاً غَيُورًا أَرَأَيْتَ لَوْ أَنَّكَ وَجَدْتَ مَعَ أُمِّ ثَابِتٍ رَجُلاً أَىَّ شَىْءٍ كُنْتَ تَصْنَعُ قَالَ كُنْتُ ضَارِبَهُمَا بِالسَّيْفِ أَنْتَظِرُ حَتَّى أَجِيءَ بِأَرْبَعَةٍ إِلَى مَا ذَاكَ قَدْ قَضَى حَاجَتَهُ وَذَهَبَ ‏.‏ أَوْ أَقُولُ رَأَيْتُ كَذَا وَكَذَا فَتَضْرِبُونِي الْحَدَّ وَلاَ تَقْبَلُوا لِي شَهَادَةً أَبَدًا ‏.‏ قَالَ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ كَفَى بِالسَّيْفِ شَاهِدًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ لاَ إِنِّي أَخَافُ أَنْ يَتَتَايَعَ فِي ذَلِكَ السَّكْرَانُ وَالْغَيْرَانُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يَعْنِي ابْنَ مَاجَهْ سَمِعْتُ أَبَا زُرْعَةَ يَقُولُ هَذَا حَدِيثُ عَلِيِّ بْنِ مُحَمَّدٍ الطَّنَافِسِيِّ وَفَاتَنِي مِنْهُ ‏.‏\hadithno{2606}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salamah bin Muhabbiq said:“When the Verse of legal punishments was revealed, it was said to Abu Thabit Sa'd bin Ubadah, who was a jealous man: ‘If you found another man with your wife, what would you do?’ He said: “I would strike them both wife the sword; do you think I should wait until I bring four (witness) and he has satisfied himself and gone away? Or should I say I saw such and such, and you will carry out the legal punishment punishment on me (for slander) and never accept my testimony thereafter?' Mention of that was made to the prophet (ﷺ) and he said: “The sword is sufficient as a witness.' Then he said: 'No (on second thought) I am afraid that the drunkard and the jealous would pursue that.” (Da'if) Abu Abdullah - meaning Ibn Majah - said: “I heard Abu Zurah saying: “This is a Hadith of Ali bin Muhammad At-Tanafisi, I did not hear it from him.”}}
\hadithdefcmd{ibnmajah}{2607}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، جَمِيعًا عَنْ أَشْعَثَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ مَرَّ بِي خَالِي - سَمَّاهُ هُشَيْمٌ فِي حَدِيثِهِ الْحَارِثَ بْنَ عَمْرٍو - وَقَدْ عَقَدَ لَهُ النَّبِيُّ صلى الله عليه وسلم لِوَاءً فَقُلْتُ لَهُ أَيْنَ تُرِيدُ فَقَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ تَزَوَّجَ امْرَأَةَ أَبِيهِ مِنْ بَعْدِهِ فَأَمَرَنِي أَنْ أَضْرِبَ عُنُقَهُ ‏.‏\hadithno{2607}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Bara bin Azib said:“My maternal uncle passed by me - (one of the narrators) Hushaim named him in his narration as Harith bin Amr - and the Prophet (ﷺ) had given him a banner to carry. I said to him: 'Where are you going?’ He said: 'The Messenger of Allah (ﷺ) has sent me to a man who married his father's wife after he died, and has commanded me to strike his neck (i.e. execute him).”}}
\hadithdefcmd{ibnmajah}{2608}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ ابْنُ أَخِي الْحُسَيْنِ الْجُعْفِيِّ، حَدَّثَنَا يُوسُفُ بْنُ مَنَازِلَ التَّيْمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ خَالِدِ بْنِ أَبِي كَرِيمَةَ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ تَزَوَّجَ امْرَأَةَ أَبِيهِ أَنْ أَضْرِبَ عُنُقَهُ وَأُصَفِّيَ مَالَهُ ‏.‏\hadithno{2608}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mu'awiyah bin Qurrah that his father said:“The Messenger of Allah (ﷺ) sent me to a man who had married his father's wife after he died, to strike his neck (execute him) and confiscate his wealth.”}}
\hadithdefcmd{ibnmajah}{2609}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا ابْنُ أَبِي الضَّيْفِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ انْتَسَبَ إِلَى غَيْرِ أَبِيهِ أَوْ تَوَلَّى غَيْرَ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ ‏"‏ ‏.‏\hadithno{2609}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas that the Messenger of Allah (ﷺ) said:“Whoever claims to belong to someone other than his father, or (a freed slave) who claims that his Wala is for other than his real master, the curse of Allah (SWT), the angels and all the people will be upon him.”}}
\hadithdefcmd{ibnmajah}{2610}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، قَالَ سَمِعْتُ سَعْدًا، وَأَبَا، بَكْرَةَ وَكُلُّ وَاحِدٍ مِنْهُمَا يَقُولُ سَمِعَتْ أُذُنَاىَ، وَوَعَى، قَلْبِي مُحَمَّدًا صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ وَهُوَ يَعْلَمُ أَنَّهُ غَيْرُ أَبِيهِ فَالْجَنَّةُ عَلَيْهِ حَرَامٌ ‏"‏ ‏.‏\hadithno{2610}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Uthman Nahdi said:“I heard Sa'd and Abu Bakrah both say that they heard directly from Muhammad (ﷺ) saying it and memorized: 'Whoever claims to belong to someone other than his father knowing the he is not his father, Paradise will be forbidden to him.”}}
\hadithdefcmd{ibnmajah}{2611}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ لَمْ يَرَحْ رَائِحَةَ الْجَنَّةِ وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ خَمْسِمِائَةِ عَامٍ ‏"‏ ‏.‏\hadithno{2611}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abdullah bin Amr that the Messenger of Allah (ﷺ) said:“Whoever claims to belong to someone other than his father will not smell the fragrance of Paradise, even though its fragrance may be detected from a distance of five hundred years.”}}
\hadithdefcmd{ibnmajah}{2612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ حَيَّانَ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُغِيرَةِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَقِيلِ بْنِ طَلْحَةَ السُّلَمِيِّ، عَنْ مُسْلِمِ بْنِ هَيْصَمٍ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي وَفْدِ كِنْدَةَ وَلاَ يَرَوْنِي أَفْضَلَهُمْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلَسْتُمْ مِنَّا ‏.‏ فَقَالَ ‏ "‏ نَحْنُ بَنُو النَّضْرِ بْنِ كِنَانَةَ لاَ نَقْفُو أُمَّنَا وَلاَ نَنْتَفِي مِنْ أَبِينَا ‏"‏ ‏.‏ قَالَ فَكَانَ الأَشْعَثُ بْنُ قَيْسٍ يَقُولُ لاَ أُوتَى بِرَجُلٍ نَفَى رَجُلاً مِنْ قُرَيْشٍ مِنَ النَّضْرِ بْنِ كِنَانَةَ إِلاَّ جَلَدْتُهُ الْحَدَّ ‏.‏\hadithno{2612}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muslim bin Haisam narrated from Ash'ath bin Qais who said:“I came to the Messenger of Allah (ﷺ) with a delegation from Kindah, and they thought that I was the best of them. I said: 'O Messenger of Allah (ﷺ) are you not from among us?' He said: 'We are the tribe of Banu Nadr bin Kinanah, and we do not attribute ourselves to our mother and we do not deny our forefathers.'”He said: “Ash'ath bin Qais used to say: 'If any man is brought to me who suggests that a man from Quraish does not belong to Nadr bin Kinanah, I would carry out the legal punishment (for slander) on him.'”}}
\hadithdefcmd{ibnmajah}{2613}{حَدَّثَنَا الْحَسَنُ بْنُ أَبِي الرَّبِيعِ الْجُرْجَانِيُّ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنِي يَحْيَى بْنُ الْعَلاَءِ، أَنَّهُ سَمِعَ بِشْرَ بْنَ نُمَيْرٍ، أَنَّهُ سَمِعَ مَكْحُولاً، يَقُولُ إِنَّهُ سَمِعَ يَزِيدَ بْنَ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ صَفْوَانَ بْنَ أُمَيَّةَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ عَمْرُو بْنُ قُرَّةَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ قَدْ كَتَبَ عَلَىَّ الشِّقْوَةَ فَمَا أُرَانِي أُرْزَقُ إِلاَّ مِنْ دُفِّي بِكَفِّي فَأْذَنْ لِي فِي الْغِنَاءِ فِي غَيْرِ فَاحِشَةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ آذَنُ لَكَ وَلاَ كَرَامَةَ وَلاَ نُعْمَةَ عَيْنٍ كَذَبْتَ أَىْ عَدُوَّ اللَّهِ لَقَدْ رَزَقَكَ اللَّهُ طَيِّبًا حَلاَلاً فَاخْتَرْتَ مَا حَرَّمَ اللَّهُ عَلَيْكَ مِنْ رِزْقِهِ مَكَانَ مَا أَحَلَّ اللَّهُ عَزَّ وَجَلَّ لَكَ مِنْ حَلاَلِهِ ‏.‏ وَلَوْ كُنْتُ تَقَدَّمْتُ إِلَيْكَ لَفَعَلْتُ بِكَ وَفَعَلْتُ قُمْ عَنِّي وَتُبْ إِلَى اللَّهِ أَمَا إِنَّكَ إِنْ فَعَلْتَ بَعْدَ التَّقْدِمَةِ إِلَيْكَ ضَرَبْتُكَ ضَرْبًا وَجِيعًا وَحَلَقْتُ رَأْسَكَ مُثْلَةً وَنَفَيْتُكَ مِنْ أَهْلِكَ وَأَحْلَلْتُ سَلَبَكَ نُهْبَةً لِفِتْيَانِ أَهْلِ الْمَدِينَةِ ‏"‏ ‏.‏ فَقَامَ عَمْرٌو وَبِهِ مِنَ الشَّرِّ وَالْخِزْىِ مَا لاَ يَعْلَمُهُ إِلاَّ اللَّهُ فَلَمَّا وَلَّى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَؤُلاَءِ الْعُصَاةُ مَنْ مَاتَ مِنْهُمْ بِغَيْرِ تَوْبَةٍ حَشَرَهُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ كَمَا كَانَ فِي الدُّنْيَا مُخَنَّثًا عُرْيَانًا لاَ يَسْتَتِرُ مِنَ النَّاسِ بِهُدْبَةٍ كُلَّمَا قَامَ صُرِعَ ‏"‏ ‏.‏\hadithno{2613}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Safwan bin Umayyah said:“We were with the Messenger of Allah (ﷺ) and Amr bin Murrah came and said: 'O Messenger of Allah (ﷺ), Allah (SWT) has decreed that I be doomed, and He has not guided me to earn a living except by beating my tambourine with my hand; give me permission to sing without doing anything immoral.' The Messenger of Allah (ﷺ) said: 'I will not give you permission, or honor you nor give you, what you want. You are lying, O enemy of Allah. Allah (SWT) has granted you a good, lawful provision, but you have chosen the provision that Allah (SWT) has forbidden to you instead of that which He has permitted. If I had warned you before, I would have done such and such to you. Get away from me and repent to Allah (SWT). If you do that again, after this warning, I will give you a painful beating and shave your head, to make an example of you, and I will banish you from among your people, and tell the young men of Al-Madinah to come and take your goods,'Amr stood up, suffering grief and humiliation that is known only to Allah (SWT). When he went away, the Prophet (ﷺ) said: 'Those sinners, whoever among them dies without having repented, Allah (SWT) will gather him on the Day of Resurrection just as he was in this world, effeminate and naked, with not even a piece of cloth to conceal him from the people. Every time he gets up, he will fall to the ground.'”}}
\hadithdefcmd{ibnmajah}{2614}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَسَمِعَ مُخَنَّثًا وَهُو يَقُولُ لِعَبْدِ اللَّهِ بْنِ أَبِي أُمَيَّةَ إِنْ يَفْتَحِ اللَّهُ الطَّائِفَ غَدًا دَلَلْتُكَ عَلَى امْرَأَةٍ تُقْبِلُ بِأَرْبَعٍ وَتُدْبِرُ بِثَمَانٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَخْرِجُوهُمْ مِنْ بُيُوتِكُمْ ‏"‏ ‏.‏\hadithno{2614}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that :the Prophet (ﷺ) entered upon her, and heard an effeminate man saying to Abdullah bin Abu Umayyah: “If Allah enable us to conquer Ta'if tomorrow, I will show you a woman who comes in on four (roll of fat) and goes out on eight” The Prophet (ﷺ) said: “Throw them out of your houses.”}}
